package at.xaxa.ledger.data.db

import androidx.room.Dao
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Update
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.data.db.Entry.EntryEntity
import kotlinx.coroutines.flow.Flow

@Dao
interface LedgerDao {
    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun addCategory(entryEntity: CategoryEntity)

    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun addEntry(entryEntity: EntryEntity)

    @Update
    suspend fun updateCategory(category: CharCategory)

    @Update
    suspend fun updateEntry(entryEntity: EntryEntity)


    @Delete
    suspend fun deleteCategory(category: CharCategory)


    @Delete
    suspend fun deleteEntry(entryEntity: EntryEntity)


    @Query("SELECT * FROM category WHERE _id = :id")
    suspend fun findCategoryById(id: Int) : CategoryEntity


    @Query("SELECT * FROM category")
    fun getAllCategory(): Flow<List<CategoryEntity>>


    @Query("SELECT * FROM transaction WHERE _id = :id")
    suspend fun findEntryById(id: Int) : EntryEntity


    @Query("SELECT * FROM transaction")
    fun getAllEntries(): Flow<List<EntryEntity>>
}
